@@ -1,5 +1,5 @@
 package Business::PayPal::API;
-$Business::PayPal::API::VERSION = '0.73';
+$Business::PayPal::API::VERSION = '0.74';
 use 5.008001;
 use strict;
 use warnings;
@@ -302,7 +302,7 @@ Business::PayPal::API - PayPal SOAP API client with sandbox support
 
 =head1 VERSION
 
-version 0.73
+version 0.74
 
 =head1 SYNOPSIS
 
@@ -819,10 +819,9 @@ calls.
 
 =head1 SEE ALSO
 
-L<SOAP::Lite>, L<https://www.paypal.com/IntegrationCenter/ic_pro_home.html>,
-L<https://www.paypal.com/IntegrationCenter/ic_expresscheckout.html>,
-L<https://www.sandbox.paypal.com/en_US/pdf/PP_Sandbox_UserGuide.pdf>,
-L<https://developer.paypal.com/en_US/pdf/PP_APIReference.pdf>
+L<SOAP::Lite>,
+L<PayPal User Guide|https://developer.paypal.com/webapps/developer/docs/classic/products>,
+L<PayPal API Reference|https://developer.paypal.com/webapps/developer/docs/api/overview>
 
 =head1 AUTHORS
 
