@@ -1,5 +1,5 @@
 package Business::PayPal::API::TransactionSearch;
-$Business::PayPal::API::TransactionSearch::VERSION = '0.73';
+$Business::PayPal::API::TransactionSearch::VERSION = '0.74';
 use 5.008001;
 use strict;
 use warnings;
@@ -89,7 +89,7 @@ Business::PayPal::API::TransactionSearch - PayPal TransactionSearch API
 
 =head1 VERSION
 
-version 0.73
+version 0.74
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,13 @@ version 0.73
         TransactionID => $transid,
     );
 
+    my $received = $pp->TransactionSearch(
+        StartDate        => '2015-11-13T00:00:00Z',
+        EndDate          => '2015-11-13T00:00:00Z',
+        Status           => 'Success',
+        TransactionClass => 'Received',
+    );
+
 =head1 DESCRIPTION
 
 L<Business::PayPal::API::TransactionSearch> implements PayPal's
